# Storage device related problems
# Author: Martin Pitt <martin.pitt@ubuntu.com>
# (C) 2009 Canonical Ltd.
# License: GPL v2 or later.

from glob import glob
import subprocess
import apport.hookutils
import time
import os

description = 'Display (X.org)'

def run(report, ui):
    prompt = 'What display problem do you observe?'
    choice = ui.choice(prompt,
        ['I don\'t know',
         'Freezes or hangs during boot or usage',
         'Crashes or restarts back to login screen',
         'Resolution is incorrect',
         'Shows screen corruption',
         'Performance is worse than expected',
         'Other display-related problem',
        ])

    if choice is None:
        raise StopIteration
    choice = problem[0]

    report.setdefault('Tags', '')

    # Tag kubuntu bugs
    if subprocess.call(['pgrep', '-u', str(os.getuid()), '-x', 'ksmserver']) == 0:
        report['Tags'] += ' kubuntu'

    # Process problems
    if choice == 0:
        return None
    if choice == 1:
        ui.information('To debug X freezes, please see https://wiki.ubuntu.com/X/Troubleshooting/Freeze')
        report['Tags'] += ' freeze'
        report['Title'] = 'Xorg freeze'
        return 'xorg'
    if choice == 2:
        ui.information('Please reproduce the crash and collect a backtrace.  See https://wiki.ubuntu.com/X/Backtracing for directions.')
        report['Tags'] += ' crash'
        report['Title'] = 'Xorg crash'
        return 'xorg'
    if choice == 3:
        report['Tags'] += ' resolution'
        return 'xorg'
    if choice == 4:
        ui.information('Please take a photo of the screen showing the corruption and attach to the bug report')
        report['Tags'] += ' corruption'
        # TODO:  Let user upload the file
        return 'xorg'
    if choice == 5:
        report['Tags'] += ' performance'
        return 'xorg'
    if choice == 6:
        return None

    return None

